Attributes

Struct Attributes 

pub struct Attributes<H, R> { /* private fields */ }
Attributes represent a collection of attribute values and that can be hardened into a Keyspace.

Implementations

Source

impl<H, R> Attributes<H, R>

pub fn new(arr: Vec<Vec<u8>>, password_hasher: H) -> Result<Self, AttrkeyError>

Construct a new collection of Attributes.

Requires at least two attribute values, and a password hasher. Returns an error when fewer than two attributes are provided.

pub fn harden( &self, constraint: u8, context: Option<&[u8]>, ) -> Result<Keyspace<R>, AttrkeyError>

Harden the attributes into a cryptographic Keyspace.

Applies password hashing to harden all attributes in parallel with salts derived from each attribute and its position. All hardened attributes are used to produce a keyspace, from which attribute-based keys can be selected.

Returns a Keyspace of the hardened attributes on success, or an error if password hashing fails.

pub fn harden_with_salts( &self, salts: &[Vec<u8>], constraint: u8, context: Option<&[u8]>, ) -> Result<Keyspace<R>, AttrkeyError>

Harden the attributes into a cryptographic Keyspace.

Applies password hashing to harden all attributes in parallel with provided salts. All hardened attributes are used to produce a keyspace, from which attribute-based keys can be selected.

Returns a Keyspace of the hardened attributes on success, or an error if password hashing fails.

pub fn len(&self) -> usize

Return the number of attributes in this collection.