pub struct Attributes<H, R> { /* private fields */ }Expand description
Attributes represent a collection of attribute values and that
can be hardened into a Keyspace.
Implementations
Sourceimpl<H, R> Attributes<H, R>where
H: PasswordHasher<PasswordHash> + Sync,
R: SeedableRng + Rng + Sync,
R::Seed: AsMut<[u8]> + Default + Zeroize,
impl<H, R> Attributes<H, R>where
H: PasswordHasher<PasswordHash> + Sync,
R: SeedableRng + Rng + Sync,
R::Seed: AsMut<[u8]> + Default + Zeroize,
Sourcepub fn new(arr: Vec<Vec<u8>>, password_hasher: H) -> Result<Self, AttrkeyError>
pub fn new(arr: Vec<Vec<u8>>, password_hasher: H) -> Result<Self, AttrkeyError>
Construct a new collection of Attributes.
Requires at least two attribute values, and a password hasher. Returns an error when fewer than two attributes are provided.
Sourcepub fn harden(
&self,
constraint: u8,
context: Option<&[u8]>,
) -> Result<Keyspace<R>, AttrkeyError>
pub fn harden( &self, constraint: u8, context: Option<&[u8]>, ) -> Result<Keyspace<R>, AttrkeyError>
Harden the attributes into a cryptographic Keyspace.
Applies password hashing to harden all attributes in parallel with salts derived from each attribute and its position. All hardened attributes are used to produce a keyspace, from which attribute-based keys can be selected.
Returns a Keyspace of the hardened attributes on success, or an error
if password hashing fails.
Sourcepub fn harden_with_salts(
&self,
salts: &[Vec<u8>],
constraint: u8,
context: Option<&[u8]>,
) -> Result<Keyspace<R>, AttrkeyError>
pub fn harden_with_salts( &self, salts: &[Vec<u8>], constraint: u8, context: Option<&[u8]>, ) -> Result<Keyspace<R>, AttrkeyError>
Harden the attributes into a cryptographic Keyspace.
Applies password hashing to harden all attributes in parallel with provided salts. All hardened attributes are used to produce a keyspace, from which attribute-based keys can be selected.
Returns a Keyspace of the hardened attributes on success, or an error
if password hashing fails.