pub struct Attributes<'a, D> { /* private fields */ }Expand description
Represents a collection of attribute values and that can be hardened into
a Keyspace using memory-hard key derivation.
Implementations
Sourceimpl<'a, D> Attributes<'a, D>where
D: Digest + CoreProxy + OutputSizeUser + Sync,
D::Core: Sync + HashMarker + UpdateCore + FixedOutputCore + BufferKindUser<BufferKind = Eager> + Default + Clone + BlockSizeUser,
<D::Core as BlockSizeUser>::BlockSize: IsLess<U256>,
Le<<D::Core as BlockSizeUser>::BlockSize, U256>: NonZero,
impl<'a, D> Attributes<'a, D>where
D: Digest + CoreProxy + OutputSizeUser + Sync,
D::Core: Sync + HashMarker + UpdateCore + FixedOutputCore + BufferKindUser<BufferKind = Eager> + Default + Clone + BlockSizeUser,
<D::Core as BlockSizeUser>::BlockSize: IsLess<U256>,
Le<<D::Core as BlockSizeUser>::BlockSize, U256>: NonZero,
Sourcepub fn new(arr: Vec<Vec<u8>>, params: Params) -> Result<Self, ArrkeyError>
pub fn new(arr: Vec<Vec<u8>>, params: Params) -> Result<Self, ArrkeyError>
Construct a new collection of Attributes.
Requires at least two attribute values, and a set of valid parameters. Returns an error when fewer than two attributes are provided.
Sourcepub fn harden(&self, salt: &[u8]) -> Result<Keyspace<D>, ArrkeyError>
pub fn harden(&self, salt: &[u8]) -> Result<Keyspace<D>, ArrkeyError>
Harden the attributes into a cryptographic Keyspace.
Applies a memory-hard key derivation function (Argon2id) to harden all attributes in parallel, using per-attribute salts derived from a shared base salt. All hardened attributes are used to produce a keyspace, from which attribute-based keys can be selected.
Returns a Keyspace of the hardened attributes on success, or an error when the memory-hard key derivation process fails.